@@ -335,15 +335,17 @@ static bool get_proc_stat(char *pid, char *format_str, struct procstat* prs,
     }
 
 
+    int comm_esize = sizeof(prs->comm) - 1;
     int comm_len = close_paren - open_paren - 1;
-    if(comm_len > 15) {
-      comm_len = 15;
+    if(comm_len > comm_esize) {
+      comm_len = comm_esize;
     }
     if(comm_len == 0) {
       goto done;
     }
 
-    strncpy(prs->comm, open_paren + 1, 15);
+    strncpy(prs->comm, open_paren + 1, comm_esize);
+    prs->comm[comm_esize] = '\0';
 
     /* address at which we pickup again, after the ')'
      * NOTE: we don't bother checking bounds since strchr didn't return NULL
